﻿#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
using Microsoft.Xna.Framework.GamerServices;
using GGJ_2015.Util;
using GGJ_2015.Scenes;
#endregion

namespace GGJ_2015
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class GGJGame : Game
    {
        public const int GWIDTH = 1600, GHEIGHT = 900;

        InputManager input = new InputManager();
        Camera2D cam;
        Scene currentScene;

        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        public GGJGame()
            : base()
        {
            graphics = new GraphicsDeviceManager(this);
            
            Window.AllowUserResizing = false;
            this.IsMouseVisible = true;

            graphics.PreferredBackBufferHeight = GHEIGHT;
            graphics.PreferredBackBufferWidth = GWIDTH;
            graphics.ApplyChanges();

            Content.RootDirectory = "Content";
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            // TODO: Add your initialization logic here

            base.Initialize();

            Block.InitaliseBlocks();
            
            cam = new Camera2D(GraphicsDevice.Viewport);
            currentScene = new GameScene(200, cam);

        }

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);

            SpriteManager.Initialise(Content, GraphicsDevice);
            // TODO: use this.Content to load your game content here
        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
            // TODO: Unload any non ContentManager content here
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            InputManager.Update();
            if (currentScene != null) currentScene.Update(gameTime);

            cam.Update(gameTime);

            InputManager.UpdateInputs();

            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.DarkGray);

            //Create a SpriteBatch to draw the background with. (Needs work)
            spriteBatch.Begin();
            spriteBatch.Draw(SpriteManager.background, new Rectangle(0, 0, GWIDTH, GHEIGHT), Color.White);
            spriteBatch.End();

            //Start the main Sprite Batch, and transform it with the camera view matrix
            spriteBatch.Begin(SpriteSortMode.Deferred, null, null, null, null, null, cam.ViewMatrix);

            if (currentScene != null) currentScene.Render(spriteBatch);

            spriteBatch.End();


            //Start the UI Sprite Batch
            spriteBatch.Begin();

            spriteBatch.Draw(SpriteManager.uiBG, new Rectangle(GWIDTH - 150, 0, 150, 130), Color.White);
            spriteBatch.Draw(SpriteManager.hudUpgrades, new Vector2(GWIDTH - 150, 0), Color.White);
          
            if (currentScene != null) currentScene.RenderUI(spriteBatch);

            spriteBatch.End();

            base.Draw(gameTime);
        }
    }
}
