﻿using GGJ_2015.Util;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace GGJ_2015.GameObjects.Entities.Projectiles
{
    public class Laser : Entity
    {
        /// <summary>
        /// This is the origin of a single frame of the laser animation
        /// </summary>
        Vector2 origin = new Vector2(0,0);

        /// <summary>
        /// This is the laser animation
        /// </summary>
        Animation laserAnim;

        /// <summary>
        /// This is the angle that the laser is at
        /// </summary>
        float rotation;

        /// <summary>
        /// These vectors represent the direction and the destination of the laser
        /// </summary>
        Vector2 direction;
        Vector2 destination;

        public Laser(Vector2 position, Vector2 target, Vector2 direction)
        {
            this.position = position;
            this.destination = target;
            this.direction = direction;
            this.velocity = new Vector2(350, 350);

            rotation = (float)(Math.Atan2(direction.Y, direction.X) + Math.PI / 2f);

            laserAnim = new Animation(SpriteManager.miningLaser, 0.07);
        }

        /// <summary>
        /// This is the update method for the laser
        /// </summary>
        /// <param name="dt">The delta time since last update</param>
        public override void Update(Microsoft.Xna.Framework.GameTime dt)
        {
            laserAnim.Update(dt);

            position.X += direction.X * velocity.X* (float)dt.ElapsedGameTime.TotalSeconds;
            position.Y += direction.Y * velocity.Y* (float)dt.ElapsedGameTime.TotalSeconds;

            if (Math.Abs(destination.X - position.X) < 5 && Math.Abs(destination.Y - position.Y) < 5) remove = true;
        }

        public override void Render(SpriteBatch batch)
        {
            batch.Draw(laserAnim.GetCurrentFrame(), position, null, Color.White, rotation, origin, 0.5f, SpriteEffects.None, 0f);
        }
        
    }
}
