﻿using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace GGJ_2015.Util
{
    /// <summary>
    /// This is a utility class to hold an run an animation
    /// </summary>
    public class Animation
    {
        /// <summary>
        /// The spritesheet of the animation
        /// </summary>
        private Texture2D[] anim;
        /// <summary>
        /// The number of frames in the animation and the current frame
        /// </summary>
        private int frames, currentFrame = 0;
        /// <summary>
        /// The timer representing when there will be a frame change
        /// </summary>
        private double frameTimer;
        /// <summary>
        /// The duration of each frame
        /// </summary>
        private double frameTime;

        /// <summary>
        /// This is the Animation Constructor
        /// </summary>
        /// <param name="animation">The spritesheet of the animation</param>
        /// <param name="frames">The number of frames in the animation</param>
        /// <param name="frameTime">The duration of each frame</param>
        public Animation(Texture2D[] animation, double frameTime)
        {
            this.anim = animation;
            this.frames = animation.Length;
            this.frameTime = frameTime;
            this.frameTimer = frameTime;
        }

        /// <summary>
        /// This method will get the current frame of the animation
        /// </summary>
        /// <returns>The animations current frame</returns>
        public Texture2D GetCurrentFrame()
        {
            return anim[currentFrame];
        }

        /// <summary>
        /// This method will update the animation and run the timers
        /// </summary>
        /// <param name="dt">The delta time since last update</param>
        public void Update(GameTime dt)
        {
            if (frameTimer < 0)
            {
                currentFrame++;
                if (currentFrame >= frames) currentFrame = 0;
            }
            else
            {
                frameTimer = frameTime;
            }
        }
    }
}
