﻿using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Input;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace GGJ_2015.Util
{
    public class InputManager
    {
        public static InputEvent up = new InputEvent();
        public static InputEvent down = new InputEvent();
        public static InputEvent left = new InputEvent();
        public static InputEvent right = new InputEvent();

        public static InputEvent w = new InputEvent();
        public static InputEvent a = new InputEvent();
        public static InputEvent s = new InputEvent();
        public static InputEvent d = new InputEvent();

        public static InputEvent e = new InputEvent();
        public static InputEvent o = new InputEvent();

        public static InputEvent lmb = new InputEvent();
        public static InputEvent rmb = new InputEvent();
        public static InputEvent space = new InputEvent();

        public static Vector2 mousePos = Vector2.Zero;


        public static KeyboardState keyState;
        public static MouseState mouseState;

        public InputManager()
        {
            keyState = Keyboard.GetState();
            mouseState = Mouse.GetState();
        }

        /// <summary>
        /// This method is used to update the keys being monitored.
        /// </summary>
        public static void Update()
        {
            //Reset the keyboard state to the current state of the keyboard
            keyState = Keyboard.GetState();
            mouseState = Mouse.GetState();

            //This area is used to update the monitored keys
            space.Set(keyState.IsKeyDown(Keys.Space));

            //Movement
            w.Set(keyState.IsKeyDown(Keys.W));
            s.Set(keyState.IsKeyDown(Keys.S));
            a.Set(keyState.IsKeyDown(Keys.A));
            d.Set(keyState.IsKeyDown(Keys.D));

            e.Set(keyState.IsKeyDown(Keys.E));
            o.Set(keyState.IsKeyDown(Keys.O));

            up.Set(keyState.IsKeyDown(Keys.Up));
            down.Set(keyState.IsKeyDown(Keys.Down));
            left.Set(keyState.IsKeyDown(Keys.Left));
            right.Set(keyState.IsKeyDown(Keys.Right));


            lmb.Set(mouseState.LeftButton == ButtonState.Pressed);
            rmb.Set(mouseState.RightButton == ButtonState.Pressed);

            mousePos = new Vector2(mouseState.X, mouseState.Y);
        }

        public static void UpdateInputs()
        {
            lmb.Update();
            rmb.Update();
            w.Update();
            s.Update();
            a.Update();
            d.Update();
            e.Update();
            o.Update();
            up.Update();
            down.Update();
            left.Update();
            right.Update();
        }

    }

    /// <summary>
    /// This class represents a key on the keyboard. It is used to monitor 
    /// the state of a key and offers some extra information based on simple 
    /// state mechanics.
    /// </summary>
    public class InputEvent
    {
        //The key states
        bool currentState = false, oldState = false;

        public InputEvent() { }

        /// <summary>
        /// This method is called every update tick. It is used to cycle the currentState and oldState
        /// </summary>
        public void Update()
        {
            oldState = currentState;
        }

        /// <summary>
        /// This method is used to set the current state of the key.
        /// </summary>
        /// <param name="newState">The new state</param>
        public void Set(bool newState)
        {
            currentState = newState;
        }

        /// <summary>
        /// This method is used to check to see if the key is down
        /// </summary>
        /// <returns>The boolean representing the key being down</returns>
        public bool IsDown()
        {
            return currentState;
        }

        /// <summary>
        /// This method is used to check to see if the key was just released
        /// </summary>
        /// <returns>The boolean representing the key being released</returns>
        public bool WasReleased()
        {
            return oldState && !currentState;
        }

        /// <summary>
        /// This method is used to check to see if the key was just pressed
        /// </summary>
        /// <returns>The boolean representing the key being pressed</returns>
        public bool WasPressed()
        {
            return currentState && !oldState;
        }
    }
}
